/*  ROSA Media Player plugin
    Julia Mineeva, Evgeniy Augin. Copyright (c) 2011 ROSA  <support@rosalab.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef CONTROLPANELFORM_H
#define CONTROLPANELFORM_H

#include <QWidget>

#include "core.h"

namespace Ui
{
class ControlPanelForm;
}

class QMenu;
class WaitWidget;

class ControlPanelForm : public QWidget
{
    Q_OBJECT

public:
    explicit ControlPanelForm( Core* core, QWidget* parent = 0 );
    ~ControlPanelForm();

    void setBorderRadius( int radius );
    void paintEvent( QPaintEvent * );
    // void setGeometry(int x, int y, int w, int h);

    void setWaitWidget( WaitWidget* waitWidget )
    {
        m_waitWidget = waitWidget;
    }
    void setParentWidget( QWidget* parent );

    bool isSeeking()
    {
        return m_isSeeking;
    }

public slots:
    void toggleFullScreenMode( bool );

protected:
    void resizeEvent ( QResizeEvent * );
    QPixmap renderSvg( QString svg, QRect rect );

protected slots:
    void playClicked();
    void volumeMute();
    void volumeFull();
    void updateVolume( int );
    void updateVolumeSlider( int );
    void setLargeSize();
    void setMediumSize();
    void setSmallSize();
    void showSizeMenu();
    void updateTimeSlider( double );
    void goToPosOnDragging( int );

    void disableActionsOnStop();
    void enableActionsOnPlaying();

    void toggleFullScreen();
    void cacheMessage( QString );
    //void centerPlayButton();

    void goToPosition( int );
    void updatePlayButton( Core::State );
    void receiveStateChangedEvent( Core::State );

signals:
    void setResolution(int);
    void setFullScreen();

private:
    Ui::ControlPanelForm *ui;

    Core*       m_core;
    QMenu*      m_menu;
    WaitWidget* m_waitWidget;
    bool        m_isSeeking;

};

#endif // CONTROLPANELFORM_H
